class QuestionsController < ApplicationController

  before_filter :find_category_id

  def allows_to?(action)
    allows_to = case(action)
    when "index", "show", "new", "create", "edit", "update" then current_user.has_role?("editor")
    when "destroy" then current_user.has_role?("admin")
    else false
    end
    return(allows_to)
  end

  def index
    if @category_id == 0
      @questions = []
    else
      @questions = Question.find_all_by_category_id(@category_id)
    end
  end

  def show
    @question = Question.find(params[:id])
  end

  def new
    @question = Question.new
    @question.category_id = @category_id
    (0..3).each do |i|
      choice = Choice.new
      choice.position = i
      @question.choices << choice
    end
    10.times {@question.assets.build}
  end

  def create
    @question = Question.new(params[:question])
    params[:choices].each_pair do |position, choice_params|
      choice = Choice.new(choice_params)
      choice.position = position.to_i
      @question.choices << choice
    end
    @question.author = current_user
    if @question.save
      if params[:commit]
        redirect_to({:action => :show, :id => @question.id, :category_id => @category_id}, :notice => t(:notice_question_created))
      else
        redirect_to({:action => :new, :category_id => @category_id}, :notice => t(:notice_question_created))
      end
    else
      render(:action => :new)
    end
  end

  def edit
    @question = Question.find(params[:id])
    10.times {@question.assets.build}
  end

  def update
    @question = Question.find(params[:id])
    error = false
    params[:choices].each_pair do |position, choice_params|
      choice = @question.choices.find_by_position(position)
      choice_params[:is_correct] = 0 unless defined?(choice_params[:is_correct]) and choice_params[:is_correct] == "1"
      if (!(choice.update_attributes(choice_params)))
        error = true
      end
    end
    @question.author = current_user unless @question.author
    if ((!error) and @question.update_attributes(params[:question]))
      redirect_to({:action => :show, :id => @question.id, :category_id => @category_id}, :notice => t(:notice_question_updated))
    else
      render(:action => :edit)
    end
  end

  def destroy
    @question = Question.find(params[:id])
    @question.destroy
    redirect_to({:action => :index, :category_id => @category_id})
  end
  
private
  
  def find_category_id
    @category_id = params[:category_id].to_i
    if @category_id == 0 and action_name != "index"
      redirect_to(questions_path, :notice => t(:notice_first_select_a_category))
    end
  end

end
