class Question < ActiveRecord::Base

  belongs_to :category
  has_many :choices, :order => :position, :dependent => :destroy
  belongs_to :author, :class_name => "User"
  has_many :assets, :as => :attachable, :dependent => :destroy
  accepts_nested_attributes_for :assets, :allow_destroy => true
  validates_presence_of :text
  validate :validate_one_choice
  
  def validate_one_choice
    correct_choices = 0
    choices.each do |choice|
      correct_choices += 1 if choice.is_correct
    end
    errors.add(:base, :one_choice) if correct_choices != 1
  end

end
